Learn R Programming

normality (version 0.0.4)

Cramer_von_Mises_test: Cramer-von Mises Normality Test

Description

An empirical distribution function (EDF)-based goodness-of-fit test that measures the overall discrepancy between the empirical and theoretical cumulative distribution functions by assigning relatively uniform weight across the entire distribution.

Usage

Cramer_von_Mises_test(
  x,
  alpha = 0.05,
  silent = FALSE,
  summary = TRUE,
  misc = FALSE
)

Value

A list.

Arguments

x

A numeric vector, at least length of 8.

alpha

Numeric (default: 0.05). Significance threshold, range from 0 to 1.

silent

Logical (default: FALSE). If FALSE, print out the results.

summary

Logical (default: TRUE). Produce a summary table.

misc

Logical (default: FALSE). Output other unimportant parameters.

References

Thode, H. C., Jr., 2002. Goodness of fit tests. Testing for normality. Marcel Dekker, New York. (Section 5.1.3, pg. 103)

Stephens, M.A., 2017. Tests Based on EDF Statistics. In: D'Agostino, R.B., Stephens, M.A. (Eds.), Goodness-of-Fit Techniques, 1st ed. Routledge, New York, (Table 4.9, pg. 127). https://doi.org/10.1201/9780203753064

Examples

Run this code
out <- Cramer_von_Mises_test(rnorm(10))
print(out$summary)

Run the code above in your browser using DataLab