Learn R Programming

normality (version 0.0.3)

Lilliefors_test: Lilliefors Normality Test

Description

Performs the Lilliefors normality test, which is an empirical distribution function (EDF)-based goodness-of-fit test derived from the Kolmogorov–Smirnov test, using the approximation proposed by Molin and Abdi (1998).

Usage

Lilliefors_test(x, alpha = 0.05, silent = FALSE, summary = TRUE, misc = FALSE)

Value

A list.

Arguments

x

A numeric vector, at least length of 8.

alpha

Numeric (default: 0.05). Significance threshold, range from 0 to 1.

silent

Logical (default: FALSE). If FALSE, print out the results.

summary

Logical (default: TRUE). Produce a summary table.

misc

Logical (default: FALSE). Output other unimportant parameters.

References

Molin, P., Abdi, H., 1998. New tables and numerical approximation for the Kolmogorov-Smirnov/Lillierfors/Van Soest test of normality. Technical report, University of Bourgogne.

Examples

Run this code
out <- Lilliefors_test(rnorm(10))
print(out$summary)

Run the code above in your browser using DataLab