Learn R Programming

normality (version 0.0.1)

cholesterol: Cholesterol data

Description

A numeric vector, the cholesterol values from a sample of 62 subjects from the Framingham Heart Study (FHS). This dataset was obtained from D'Agostino paper.

Usage

cholesterol

Arguments

Format

A numeric vector length of 62.

References

D’agostino, R.B., Belanger, A., D’agostino, R.B., 1990. A Suggestion for Using Powerful and Informative Tests of Normality. The American Statistician 44, 316–321. https://doi.org/10.1080/00031305.1990.10475751