powered by
A handy wrapper for data normality assessment using the Shapiro-Wilk-Royston, D'Agostino-Pearson, and Anderson-Darling tests.
is_normal(data, formula = NULL, alpha = 0.05, sensitivity = 2, summary = FALSE)
A boolean value (or a list if summary = TRUE).
summary = TRUE
A data frame or a numeric vector.
Formula (default: NULL). If data is a data frame, define the val ~ group.
data
Significance threshold, range from 0 to 1 (default: 0.05).
Numeric, range from 1 to 3 (default: 2). The greater the value, the greater chance to consider as non-normal.
Logical (default: FALSE). If TRUE, show the summary table.
TRUE
is_normal(iris, Sepal.Length ~ Species)
Run the code above in your browser using DataLab